@@ -1,5 +1,4 @@
-#
-# Copyright (C) 2004-2012  Kouhei Sutou <kou@cozmixng.org>
+# Copyright (C) 2004-2014  Kouhei Sutou <kou@cozmixng.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,17 +48,11 @@ module Rabbit
         require "rabbit/canvas"
         GC.enable
 
-        if @options.save_as_image
-          do_save_as_image
-        elsif @options.print
-          do_print
-        elsif @options.server
-          do_server
-        else
-          do_display
-        end
+        succeeded = __send__("do_#{@options.action}")
 
         ::Rabbit.cleanup
+
+        succeeded
       end
 
       private
@@ -82,6 +75,7 @@ module Rabbit
             adjust_rest_arguments(console, parser, options)
           end
 
+          options.action = :display
           options.options_file = ".rabbit"
           options.theme = "default"
           options.theme_specified = false
@@ -91,19 +85,18 @@ module Rabbit
           options.source_type = :auto
           options.full_screen = false
           options.index_mode = false
+          options.initial_slide = 0
           options.geometry = nil
           options.width = 800
           options.height = 600
           options.paper_width = nil
           options.paper_height = nil
-          options.save_as_image = false
           options.saved_image_base_name = nil
           options.saved_image_type = "png"
           options.output_html = false
           options.output_index_html = false
           options.rss_base_uri = nil
           options.encoding = nil
-          options.print = false
           options.print_out_filename = nil
           options.slides_per_page = 1
           options.draw_scaled_image = nil
@@ -123,7 +116,6 @@ module Rabbit
           options.use_xmlrpc = false
           options.xmlrpc_host = "0.0.0.0"
           options.xmlrpc_port = 10104
-          options.server = false
           options.default_public_level = "all"
           options.public_level = nil
           options.migemo_dictionary_search_path = [
@@ -223,6 +215,12 @@ module Rabbit
             options.index_mode = bool
           end
 
+          parser.on("--initial-slide=N", Integer,
+                    _("Show the Nth slide. (zero-based)"),
+                    "(#{options.initial_slide})") do |n|
+            options.initial_slide = n
+          end
+
 
           parser.category _("Size")
 
@@ -264,7 +262,7 @@ module Rabbit
 
           parser.on("-s", "--save-as-image",
                     _("Save as image and exit.")) do
-            options.save_as_image = true
+            options.action = :save_as_image
           end
 
           parser.on("-i", "--saved-image-type=TYPE",
@@ -309,7 +307,7 @@ module Rabbit
 
           parser.on("-p", "--print",
                     _("Print and exit.")) do
-            options.print = true
+            options.action = :print
           end
 
           parser.on("-o", "--output-filename=FILENAME",
@@ -514,10 +512,10 @@ module Rabbit
 
           parser.category _("Server")
 
-          parser.on("--[no-]server",
+          parser.on("--server",
                     _("Specify whether to run as server."),
-                    "(#{options.server})") do |bool|
-            options.server = bool
+                    "(#{options.server})") do
+            options.action = :server
           end
 
           parser.category _("Public level")
@@ -591,11 +589,16 @@ module Rabbit
 
           parser.category _("Others")
 
+          parser.on("--check-syntax",
+                    _("Check slide source syntax and exit.")) do
+            options.action = :check_syntax
+          end
+
           parser.on("--[no-]show-native-window-id",
                     _("Show a native window ID of the Rabbit window if available."),
                     _("e.g. The ID is the ID of X resource on X window system."),
                     "(#{options.show_native_window_id})") do |bool|
-              options.show_native_window_id = bool
+            options.show_native_window_id = bool
           end
         end
       end
@@ -807,8 +810,10 @@ module Rabbit
         parse(canvas, source)
         canvas.print
         canvas.quit
+        true
       rescue ::Rabbit::NoPrintSupportError
         @logger.error($!.message)
+        false
       end
 
       def do_save_as_image
@@ -827,6 +832,8 @@ module Rabbit
         canvas.activate("ToggleIndexMode") if @options.index_mode
         canvas.save_as_image
         canvas.quit
+
+        true
       end
 
       def do_display
@@ -855,6 +862,7 @@ module Rabbit
         end
         apply_theme_if_need(frame)
         parse(frame, source, !Utils.windows?)
+        canvas.move_to_if_can(@options.initial_slide)
         canvas.activate("ToggleIndexMode") if @options.index_mode
 
         front = make_front(canvas)
@@ -863,6 +871,8 @@ module Rabbit
         setup_xmlrpc(front) if @options.use_xmlrpc
 
         Gtk.main
+
+        true
       end
 
       def do_server
@@ -904,6 +914,29 @@ module Rabbit
           end
           DRb.thread.join
         end
+
+        true
+      end
+
+      def do_check_syntax
+        source = make_source
+        renderer = Renderer.printable_renderer(1)
+        canvas = make_canvas(renderer)
+        exception = nil
+        begin
+          canvas.parse(source) do |_exception|
+            exception = _exception
+          end
+        rescue
+          exception = $!
+        end
+
+        if exception
+          @logger.info(exception.message)
+          false
+        else
+          true
+        end
       end
     end
   end
