@@ -54,24 +54,21 @@ module Rabbit
           append("#{prog_name}: ", "prog_name")
         end
       end
-      
+
       def log_message(message)
-        unless GLib.utf8_validate(message)
-          message = GLib.filename_to_utf8(message)
-        end
         append(message, "message")
         append("\n")
       end
 
       def append(text, *tags)
         iter = @buffer.get_iter_at_offset(-1)
-        @buffer.insert_with_tags(iter, text, *tags)
+        @buffer.insert_with_tags(iter, text.encode("UTF-8"), *tags)
       end
 
       def title
         _("Rabbit Error Dialog")
       end
-      
+
       def init_dialog(width=@width, height=@height)
         flags = 0
         buttons = [
@@ -93,7 +90,7 @@ module Rabbit
           true
         end
       end
-      
+
       def set_dialog_response
         @dialog.signal_connect("response") do |widget, event|
           case event
@@ -112,7 +109,7 @@ module Rabbit
           false
         end
       end
-      
+
       def set_dialog_accel_group
         accel_group = Gtk::AccelGroup.new
         mod = Gdk::Window::ModifierType.new
