@@ -1,6 +1,8 @@
-require 'cairo'
+require "cairo"
+require "stringio"
 
-require 'rabbit/renderer/kernel'
+require "rabbit/image-data-loader"
+require "rabbit/renderer/kernel"
 
 module Cairo
   class Context
@@ -340,10 +342,10 @@ module Rabbit
         end
 
         def make_layout(text)
-          attrs, text = Pango.parse_markup(text)
+          attributes, text = Pango.parse_markup(text)
           layout = @context.create_pango_layout
           layout.text = text
-          layout.set_attributes(attrs)
+          layout.attributes = attributes
           set_font_resolution(layout.context)
           @context.update_pango_layout(layout)
           layout
@@ -488,15 +490,17 @@ module Rabbit
           return unless params
 
           dim = handle.dimensions
-          surface = ::Cairo::ImageSurface.new(:argb32, width, height)
-          context = ::Cairo::Context.new(surface)
-          context.scale(width / dim.width, height / dim.height)
-          context.render_rsvg_handle(handle)
-          png = Tempfile.new("rabbit-cairo-svg-renderer")
-          context.target.write_to_png(png.path)
-          context.target.finish
-          pixbuf = Gdk::Pixbuf.new(png.path)
-          _draw_reflected_pixbuf(pixbuf, x, y, params)
+          ::Cairo::ImageSurface.new(:argb32, width, height) do |surface|
+            ::Cairo::Context.new(surface) do |context|
+              context.scale(width / dim.width, height / dim.height)
+              context.render_rsvg_handle(handle)
+              png = StringIO.new
+              context.target.write_to_png(png)
+              loader = ImageDataLoader.new(png.string)
+              loader.load
+              _draw_reflected_pixbuf(loader.pixbuf, x, y, params)
+            end
+          end
         end
 
         def set_line_options(params)
