@@ -5,14 +5,12 @@ require 'rabbit/rabbit'
 
 module Rabbit
   module Source
-
     module Base
-
       def self.append_features(klass)
         super
         klass.send(:include, GetText)
       end
-      
+
       attr_reader :base, :tmp_base
       attr_accessor :encoding, :force_modified
 
@@ -31,33 +29,36 @@ module Rabbit
 
       def reset
       end
-      
+
       def read
         if need_read?
           @source = _read
-          if @encoding.nil?
+          case @encoding
+          when nil
             enc = guess_encoding(@source)
-          else
+          when Encoding
             enc = @encoding
+          else
+            enc = Encoding.find(@encoding)
           end
 
-          if /\Autf-?8\z/i =~ enc
-            @source.force_encoding(enc) if @source.respond_to?(:force_encoding)
+          if enc == Encoding::UTF_8
+            @source.force_encoding(enc)
           else
-            @source = convert_encoding("UTF-8", enc, @source)
+            @source = @source.encode(Encoding::UTF_8, enc)
           end
         end
         @source
       end
-      
+
       def modified?
         @force_modified or need_read?
       end
-      
+
       def need_read?
         @source.nil?
       end
-      
+
       def full_path(path)
         if @base_uri.nil? or @base_uri.relative?
           ::File.join(@base, path)
@@ -67,24 +68,24 @@ module Rabbit
           (uri + path).to_s
         end
       end
-      
+
       def open_full_path(path, mode="rb")
         open(full_path(path), mode) do |f|
           yield f
         end
       end
-      
+
       def old?(current, get_latest_method_name)
         current.nil? or
           (current and __send__(get_latest_method_name) > current)
       end
-      
+
       def tmp_dir_name
-        dir = ::File.join(@tmp_base, TMP_DIR_NAME)  
+        dir = ::File.join(@tmp_base, TMP_DIR_NAME)
         FileUtils.mkdir_p(dir) unless ::File.exist?(dir)
         dir
       end
-      
+
       def base=(new_value)
         if new_value.nil?
           init_base
@@ -127,30 +128,14 @@ module Rabbit
       end
 
       def guess_encoding(str)
+        return Encoding::UTF_8 if utf8_encoding?(str)
+
         require 'nkf'
-        case NKF.guess(str)
-        when NKF::JIS
-          "ISO-2022-JP"
-        when NKF::EUC
-          "eucJP"
-        when NKF::SJIS
-          "CP932"
-        when NKF::UTF16
-          "UTF-16"
-        when NKF::UTF32
-          "UTF-32"
-        else
-          "UTF-8"
-        end
+        NKF.guess(str)
       end
 
-      def convert_encoding(to, from, str)
-        if str.respond_to?(:encode)
-          str.encode(to, from)
-        else
-          require "iconv"
-          Iconv.conv(to, from, str)
-        end
+      def utf8_encoding?(string)
+        string.dup.force_encoding(Encoding::UTF_8).valid_encoding?
       end
 
       def extract_extension(path)
@@ -173,7 +158,7 @@ module Rabbit
         update_last_access_time if result
         result
       end
-      
+
       private
       def update_last_access_time
         @last_access_time = Time.now
@@ -183,6 +168,5 @@ module Rabbit
         Time.now - @last_access_time > MINIMUM_ACCESS_TIME
       end
     end
-    
   end
 end
