@@ -65,8 +65,12 @@ module Rabbit
       def draw_mark(indent_width, width_or_proc, height_or_proc, name=nil)
         indent(indent_width, name) do |item, canvas, x, y, w, h|
           first_text = item.elements.first
-          text_height = first_text.first_line_height
-          text_height += first_text.padding_top + first_text.padding_bottom
+          if first_text
+            text_height = first_text.first_line_height
+            text_height += first_text.padding_top + first_text.padding_bottom
+          else
+            text_height = item.height
+          end
 
           if width_or_proc.respond_to?(:call)
             mark_width = width_or_proc.call(item, canvas)
@@ -82,7 +86,8 @@ module Rabbit
           adjust_y = ((text_height / 2.0) - (mark_height / 2.0)).ceil
 
           indent_base_x = item.x - mark_width
-          indent_base_y = item.base_y + first_text.margin_top + adjust_y
+          indent_base_y = item.base_y + adjust_y
+          indent_base_y += first_text.margin_top if first_text
           width = mark_width
           height = mark_height
           yield(item, canvas, indent_base_x, indent_base_y, width, height)
@@ -173,7 +178,7 @@ module Rabbit
               args = size + [fill_color]
               canvas.draw_rectangle(true, *args)
             end
-            
+
             if frame_color
               args = size + [frame_color, {:line_width => frame_width}]
               canvas.draw_rectangle(false, *args)
@@ -186,7 +191,7 @@ module Rabbit
               usw = fw + shadow_width - shadow_offset
               ush = shadow_width
               canvas.draw_rectangle(true, usx, usy, usw, ush, shadow_color)
-      
+
               # Right Shadow
               rsx = fx + fw + frame_width
               rsy = fy + shadow_offset
@@ -248,7 +253,7 @@ module Rabbit
 
       def apply_theme(name)
         entry = find_theme(name)
-        src = File.open(entry.theme_file) do |f|
+        src = File.open(entry.theme_file, "r:utf-8") do |f|
           f.read
         end
         in_theme(entry) do
@@ -312,7 +317,7 @@ module Rabbit
           "@#{x}_large_#{$2}font_size"
         end
       end
-      
+
       def include_theme(name)
         begin
           apply_theme(name)
@@ -340,7 +345,7 @@ module Rabbit
       def logger
         canvas.logger
       end
-      
+
       def print?
         canvas.printable?
       end
@@ -352,11 +357,11 @@ module Rabbit
       def theme_exit(message=nil)
         raise ThemeExit.new(message)
       end
-      
+
       def slides_per_page
         canvas.slides_per_page
       end
-      
+
       def set_foreground(color)
         canvas.foreground = canvas.make_color(color)
       end
@@ -444,7 +449,7 @@ module Rabbit
           super
         end
       end
-      
+
       def _match(current, *paths)
         last_path_index = paths.size - 1
         paths.each_with_index do |path, i|
@@ -462,7 +467,7 @@ module Rabbit
                   path === element
                 end
               end
-              
+
               if i != last_path_index
                 working.inject([]) do |result, elem|
                   if elem.respond_to?(:elements)
@@ -474,7 +479,7 @@ module Rabbit
               else
                 working
               end
-              
+
             end
           end
         end
