@@ -1,7 +1,3 @@
-if @title_background_image.nil?
-  theme_exit("must specify @title_background_image!!")
-end
-
 @title_background_image_properties ||= {}
 default_title_backgroud_image_properties = {
   "as_large_as_possible" => true,
@@ -17,8 +13,13 @@ match(TitleSlide) do |slides|
       value = value.to_s if value.is_a?(Symbol)
       image_properties[key.to_s.gsub(/-/, "_")] = value
     end
+    background_image = slide["background-image"] || @title_background_image
+    if background_image.nil?
+      theme_exit("must specify 'background-image' slide property or " \
+                 "@title_background_image!!")
+    end
     properties = {
-      :file_name => find_file(@title_background_image),
+      :file_name => find_file(background_image),
       :proc_name => "title-background-image",
       :properties => image_properties,
     }
